Create, maintain, validate, and publish small agent-authored Rust libraries.
Structs
- Check
Result - The outcome of a complete (or fail-fast) Rust library validation run.
- Check
Stage Result - Captured output from one validation stage.
- Kcode
Rust Libs - Entry point for creating and opening managed Rust libraries.
- Opened
Rust Lib - A managed Rust library whose complete file set was loaded when it was opened.
- Rust
LibDocs - The agent-facing metadata stored in a managed Rust library.
- Rust
LibFile - A complete text file in a managed Rust library.
- Rust
LibPath - A canonical, UTF-8 path to a file relative to a managed Rust library root.
Enums
- Check
Stage - A stage in the standardized Rust validation pipeline.
- Error
- An error that prevented a Rust library operation, validation run, or publication.
Type Aliases
- Result
- The result type returned by this crate.