pub struct KcodeRustLibs { /* private fields */ }Expand description
Entry point for creating and opening managed Rust libraries.
Implementations
Sourceimpl KcodeRustLibs
impl KcodeRustLibs
Sourcepub fn new(
rust_libs_root: impl Into<PathBuf>,
crates_io_registry_token: impl Into<String>,
) -> Result<Self>
pub fn new( rust_libs_root: impl Into<PathBuf>, crates_io_registry_token: impl Into<String>, ) -> Result<Self>
Use rust_libs_root as the persistent library directory and retain the supplied crates.io
registry token in memory for publication.
Sourcepub fn create_rust_lib(&self, name: &str) -> Result<OpenedRustLib>
pub fn create_rust_lib(&self, name: &str) -> Result<OpenedRustLib>
Create a minimal managed Rust library and return it already loaded.
Sourcepub fn open_rust_lib(&self, name: &str) -> Result<OpenedRustLib>
pub fn open_rust_lib(&self, name: &str) -> Result<OpenedRustLib>
Open an existing managed Rust library and recursively load all of its current files.