Crate kcode_rust_libs

Crate kcode_rust_libs 

Create, maintain, validate, and publish small agent-authored Rust libraries.

Structs

CheckResult
The outcome of a complete (or fail-fast) Rust library validation run.
CheckStageResult
Captured output from one validation stage.
KcodeRustLibs
Entry point for creating and opening managed Rust libraries.
OpenedRustLib
A managed Rust library whose complete file set was loaded when it was opened.
RustLibDocs
The agent-facing metadata stored in a managed Rust library.
RustLibFile
A complete text file in a managed Rust library.
RustLibPath
A canonical, UTF-8 path to a file relative to a managed Rust library root.

Enums

CheckStage
A stage in the standardized Rust validation pipeline.
Error
An error that prevented a Rust library operation, validation run, or publication.

Type Aliases

Result
The result type returned by this crate.